@@ -208,6 +208,9 @@ class Simulation:
                 plt.plot(abs(self.truncatedResults[:,entry]), label=str(self.dictionaryParameters.entries[entry]))
         ax.legend()
 
+    def GetAverageResult(self, indices):
+        return np.average(self.results[:,indices], 1)
+
     @staticmethod
     def Import(filename, simulationName):
         if ".mrf" in filename:
